#ifndef MYLONGSTRING_H_
#define MYLONGSTRING_H_

#include"GraphBase.h"

#define dMYLONGSTRING_LENGTH 260

class TMyLongString{
	private:
		char TmpChar[dMYLONGSTRING_LENGTH];
	public:
		char Text[dMYLONGSTRING_LENGTH];
	public:
		void Clear(void);
	
		void FromInt(int d);
	
		void FromUInt6Dg(unsigned int data);
		void FromUInt4Dg(unsigned int data);
		void FromUInt3Dg(unsigned int data);
		void FromUInt2Dg(unsigned int data);
	
		int GetLength(void);
		int GetEndPst(void);
		void AddOnDgMax6(unsigned int data);
		void AddOn6Dg(unsigned int data);
		void AddOn4Dg(unsigned int data);
		void AddOn3Dg(unsigned int data);
		void AddOn2Dg(unsigned int data);
	
		void FormFloat(float fd);
		int ToInteger(void);
		float ToFloat(void);
	
		void FromStr(const char *source);
		void FromStr(      char *source);
		void AddOnStr(const char *source);
		void AddOnStr(      char *source);
		void ToStr(char *Dest, unsigned int len);
		void Insert(const char *source, int Pst);
		void Insert(char *source, int Pst);
		unsigned int Delete(int Pst);

		static void sClear(char *dest);
		static void sFromStr(char *source, char *dest);
		static void sFromStr(const char *source, char *dest);
		static void sFrom3Dg(unsigned int d, char *dest);
		static void sFrom4Dg(unsigned int d, char *dest);
		static void sAddOnStr(const char *source, char *dest);
		static void sAddOnDgMax6(unsigned int data, char *dest);
		static void sAddOn5Dg(unsigned int d, char *dest);
		static void sAddOn4Dg(unsigned int d, char *dest);
		static void sAddOn3Dg(unsigned int d, char *dest);
		static void sAddOn2Dg(unsigned int d, char *dest);
		static void sAddOn1Dg(unsigned int d, char *dest);
		static int sGetLen(char *source);
		static void sFillFixLen(char *source, unsigned int aLen);
		static int sToInteger(char *Src);
};


#endif









